# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import pulpcore.client.pulp_rpm
from pulpcore.client.pulp_rpm.models.inline_response2001 import InlineResponse2001  # noqa: E501
from pulpcore.client.pulp_rpm.rest import ApiException

class TestInlineResponse2001(unittest.TestCase):
    """InlineResponse2001 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test InlineResponse2001
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = pulpcore.client.pulp_rpm.models.inline_response2001.InlineResponse2001()  # noqa: E501
        if include_optional :
            return InlineResponse2001(
                count = 123, 
                next = '0', 
                previous = '0', 
                results = [
                    pulpcore.client.pulp_rpm.models.rpm/distribution_tree_response.rpm.DistributionTreeResponse(
                        pulp_href = '0', 
                        header_version = '0', 
                        release_name = '0', 
                        release_short = '0', 
                        release_version = '0', 
                        release_is_layered = True, 
                        base_product_name = '0', 
                        base_product_short = '0', 
                        base_product_version = '0', 
                        arch = '0', 
                        build_timestamp = 1.337, 
                        instimage = '0', 
                        mainimage = '0', 
                        discnum = 56, 
                        totaldiscs = 56, 
                        addons = [
                            pulpcore.client.pulp_rpm.models.addon_response.AddonResponse(
                                addon_id = '0', 
                                uid = '0', 
                                name = '0', 
                                type = '0', 
                                packages = '0', )
                            ], 
                        checksums = [
                            pulpcore.client.pulp_rpm.models.checksum_response.ChecksumResponse(
                                path = '0', 
                                checksum = '0', )
                            ], 
                        images = [
                            pulpcore.client.pulp_rpm.models.image_response.ImageResponse(
                                name = '0', 
                                path = '0', 
                                platforms = '0', 
                                artifact = pulpcore.client.pulp_rpm.models.artifact_response.ArtifactResponse(
                                    pulp_href = '0', 
                                    pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    file = '0', 
                                    size = 56, 
                                    md5 = '0', 
                                    sha1 = '0', 
                                    sha224 = '0', 
                                    sha256 = '0', 
                                    sha384 = '0', 
                                    sha512 = '0', ), )
                            ], 
                        variants = [
                            pulpcore.client.pulp_rpm.models.variant_response.VariantResponse(
                                variant_id = '0', 
                                uid = '0', 
                                name = '0', 
                                type = '0', 
                                packages = '0', 
                                source_packages = '0', 
                                source_repository = '0', 
                                debug_packages = '0', 
                                debug_repository = '0', 
                                identity = '0', )
                            ], )
                    ]
            )
        else :
            return InlineResponse2001(
        )

    def testInlineResponse2001(self):
        """Test InlineResponse2001"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
